@@ -27,6 +27,11 @@ from dbt.adapters.contracts.relation import (
     RelationConfig,
     RelationType,
 )
+from dbt.adapters.relation_configs import (
+    RelationConfigBase,
+    RelationConfigValidationMixin,
+    RelationConfigValidationRule,
+)
 from dbt.adapters.exceptions import (
     ApproximateMatchError,
     MultipleDatabasesNotAllowedError,
@@ -45,6 +50,51 @@ class EventTimeFilter(FakeAPIObject):
     end: Optional[datetime] = None
 
 
+@dataclass(frozen=True, eq=False, repr=False)
+class FunctionConfig(RelationConfigBase, RelationConfigValidationMixin):
+    language: str
+    type: str
+    runtime_version: Optional[str] = None
+    entry_point: Optional[str] = None
+
+    def _validate_runtime_version(self) -> bool:
+        if self.language == "python":
+            return self.runtime_version is not None
+        else:
+            return True
+
+    def _validate_entry_point(self) -> bool:
+        if self.language == "python":
+            return self.entry_point is not None
+        else:
+            return True
+
+    @property
+    def validation_rules(self) -> Set[RelationConfigValidationRule]:
+        return {
+            RelationConfigValidationRule(
+                validation_check=self.language != "" and self.language is not None,
+                validation_error=DbtRuntimeError("A `language` is required for functions"),
+            ),
+            RelationConfigValidationRule(
+                validation_check=self.type != "" and self.type is not None,
+                validation_error=DbtRuntimeError("A `type` is required for functions"),
+            ),
+            RelationConfigValidationRule(
+                validation_check=self.language != "python" or self.runtime_version is not None,
+                validation_error=DbtRuntimeError(
+                    "A `runtime_version` is required for python functions"
+                ),
+            ),
+            RelationConfigValidationRule(
+                validation_check=self.language != "python" or self.entry_point is not None,
+                validation_error=DbtRuntimeError(
+                    "An `entry_point` is required for python functions"
+                ),
+            ),
+        }
+
+
 @dataclass(frozen=True, eq=False, repr=False)
 class BaseRelation(FakeAPIObject, Hashable):
     path: Path
@@ -467,6 +517,22 @@ class BaseRelation(FakeAPIObject, Hashable):
     def get_relation_type(cls) -> Type[RelationType]:
         return RelationType
 
+    def get_function_config(self, model: Dict[str, Any]) -> Optional[FunctionConfig]:
+        # TODO: We shouldn't have to check the model.resource_type here. We should be alble to do self.is_function instead.
+        # However, somehow when we get here self.type is None, and thus self.is_function is False.
+        if model.get("resource_type") == "function":
+            return FunctionConfig(
+                language=model.get("language", ""),
+                type=model.get("config", {}).get("type", ""),
+                runtime_version=model.get("config", {}).get("runtime_version", None),
+                entry_point=model.get("config", {}).get("entry_point", None),
+            )
+        else:
+            return None
+
+    def get_function_macro_name(self, config: FunctionConfig) -> str:
+        return f"{config.type}_function_{config.language}"
+
 
 Info = TypeVar("Info", bound="InformationSchema")
 
